@@ -38,6 +38,9 @@ import org.sejda.core.context.DefaultSejdaContext;
 import org.sejda.core.context.SejdaContext;
 import org.sejda.core.support.util.StringUtils;
 import org.sejda.model.exception.TaskException;
+import org.sejda.model.exception.TaskIOException;
+import org.sejda.model.input.FileSource;
+import org.sejda.model.input.PdfFileSource;
 import org.sejda.model.input.PdfStreamSource;
 import org.sejda.model.input.StreamSource;
 import org.sejda.model.parameter.base.TaskParameters;
@@ -51,7 +54,7 @@ import org.sejda.sambox.pdmodel.graphics.image.PDImageXObject;
 import org.sejda.sambox.text.PDFTextStripperByArea;
 
 import java.awt.*;
-import java.io.IOException;
+import java.io.*;
 import java.util.ArrayList;
 import java.util.Iterator;
 import java.util.List;
@@ -75,6 +78,8 @@ public abstract class BaseTaskTest<T extends TaskParameters> implements Testable
     }
 
     public void execute(TaskParameters parameters) {
+        testContext.listenForTaskFailure();
+        testContext.listenForTaskWarnings();
         service.execute(parameters);
     }
 
@@ -135,6 +140,12 @@ public abstract class BaseTaskTest<T extends TaskParameters> implements Testable
                 randomAlphanumeric(16) + ".pdf");
     }
 
+    public PdfFileSource customInputAsFileSource(String path) {
+        String filename = new File(path).getName();
+        InputStream in = getClass().getClassLoader().getResourceAsStream(path);
+        return PdfFileSource.newInstanceNoPassword(streamToTmpFile(in, filename));
+    }
+
     public PdfStreamSource customInput(String path, String name) {
         requireNotBlank(name, "Name cannot be blank");
         return PdfStreamSource.newInstanceNoPassword(getClass().getClassLoader().getResourceAsStream(path), name);
@@ -155,37 +166,32 @@ public abstract class BaseTaskTest<T extends TaskParameters> implements Testable
         return StreamSource.newInstance(getClass().getClassLoader().getResourceAsStream(path), filename);
     }
 
-    public void withPageText(PDPage page, Consumer<String> callback) {
-        PDFTextStripperByArea textStripper;
+    public FileSource customNonPdfInputAsFileSource(String path) {
+        String filename = new File(path).getName();
+        InputStream in = getClass().getClassLoader().getResourceAsStream(path);
+        return FileSource.newInstance(streamToTmpFile(in, filename));
+    }
+
+    private File streamToTmpFile(InputStream in, String filename) {
         try {
-            textStripper = new PDFTextStripperByArea();
-            PDRectangle pageSize = page.getCropBox();
-            Rectangle cropBoxRectangle = new Rectangle(0, 0, (int) pageSize.getWidth(), (int) pageSize.getHeight());
-            if(page.getRotation() == 90 || page.getRotation() == 270) {
-                cropBoxRectangle = new Rectangle(0, 0, (int) pageSize.getHeight(), (int) pageSize.getWidth());
-            }
-            textStripper.setSortByPosition(true);
-            textStripper.addRegion("area1", cropBoxRectangle);
-            textStripper.extractRegions(page);
-            callback.accept(textStripper.getTextForRegion("area1"));
-        } catch (IOException e) {
-            fail(e.getMessage());
+            File tmp = org.sejda.core.support.io.IOUtils.createTemporaryBufferWithName(filename);
+            OutputStream out = new BufferedOutputStream(new FileOutputStream(tmp));
+            IOUtils.copy(in, out);
+            IOUtils.closeQuietly(out);
+            IOUtils.closeQuietly(in);
+            return tmp;
+        } catch (IOException | TaskIOException ex) {
+            throw new RuntimeException(ex);
         }
+
     }
 
     public void assertPageText(PDPage page, String text) {
-        withPageText(page, pageText -> {
-            assertEquals(text, pageText.replaceAll("[^A-Za-z0-9]", ""));
-        });
+        org.sejda.core.service.TestUtils.assertPageText(page, text);
     }
 
     public void assertPageTextContains(PDPage page, String text) {
-        withPageText(page, pageText -> {
-            // ignores whitespace
-            pageText = StringUtils.normalizeWhitespace(pageText);
-            pageText = pageText.replaceAll("\\s", "");
-            assertThat(pageText, containsString(text));
-        });
+        org.sejda.core.service.TestUtils.assertPageTextContains(page, text);
     }
 
     public void assertMediaBox(PDPage page, float width, float height) {
@@ -194,10 +200,7 @@ public abstract class BaseTaskTest<T extends TaskParameters> implements Testable
     }
 
     public <T> List<T> getAnnotationsOf(PDPage page, Class<T> clazz) {
-        return iteratorToList(page.getAnnotations().stream()
-                .filter(a -> clazz.isInstance(a))
-                .map(a -> (T) a)
-                .iterator());
+        return org.sejda.core.service.TestUtils.getAnnotationsOf(page, clazz);
     }
 
     // returns 1-based page numbers
@@ -221,12 +224,4 @@ public abstract class BaseTaskTest<T extends TaskParameters> implements Testable
         }
         return result;
     }
-
-    public <T> List<T> iteratorToList(Iterator<T> iterator) {
-        List<T> result = new ArrayList<>();
-        while(iterator.hasNext()) {
-            result.add(iterator.next());
-        }
-        return result;
-    }
 }
