@@ -123,6 +123,12 @@ public class TaskTestContext implements Closeable {
         return this;
     }
 
+    /**
+     * Initialize the given params with a directory as {@link FileOrDirectoryTaskOutput}
+     * 
+     * @param params
+     * @return
+     */
     public TaskTestContext directoryOutputTo(SingleOrMultipleOutputTaskParameters params) throws IOException {
         this.fileOutput = Files.createTempDirectory("SejdaTest").toFile();
         this.fileOutput.deleteOnExit();
@@ -130,6 +136,19 @@ public class TaskTestContext implements Closeable {
         return this;
     }
 
+    /**
+     * Initialize the given params with a pdf file as {@link FileOrDirectoryTaskOutput}
+     * 
+     * @param params
+     * @return
+     */
+    public TaskTestContext pdfOutputTo(SingleOrMultipleOutputTaskParameters params) throws IOException {
+        this.fileOutput = Files.createTempFile("SejdaTest", ".pdf").toFile();
+        this.fileOutput.deleteOnExit();
+        params.setOutput(new FileOrDirectoryTaskOutput(fileOutput));
+        return this;
+    }
+
     /**
      * asserts the creator has been set to the info dictionary
      * 
@@ -423,6 +442,11 @@ public class TaskTestContext implements Closeable {
      * @throws IOException
      */
     public PDDocument assertTaskCompleted(String password) throws IOException {
+        // First and foremost, check if the task failed.
+        this.assertTaskDidNotFail();
+
+        // look at outputs
+        // TODO: ignore leftover tmp buffers while doing this
         if (nonNull(fileOutput)) {
             if (fileOutput.isDirectory()) {
                 File[] files = fileOutput.listFiles();
@@ -457,7 +481,12 @@ public class TaskTestContext implements Closeable {
         }
     };
 
+    @Deprecated
     public void expectTaskWillFail() {
+        listenForTaskFailure();
+    }
+
+    public void listenForTaskFailure() {
         taskFailureCause = null;
         GlobalNotificationContext.getContext().removeListener(failureListener);
         GlobalNotificationContext.getContext().addListener(failureListener);
@@ -468,7 +497,16 @@ public class TaskTestContext implements Closeable {
         assertThat(taskFailureCause.getMessage(), startsWith(message));
     }
 
+    public void assertTaskDidNotFail() {
+        assertNull("Task failed", taskFailureCause);
+    }
+
+    @Deprecated
     public void expectTaskWillProduceWarnings() {
+        listenForTaskWarnings();
+    }
+
+    public void listenForTaskWarnings() {
         taskWarnings = new ArrayList<>();
         GlobalNotificationContext.getContext().removeListener(warningsListener);
         GlobalNotificationContext.getContext().addListener(warningsListener);
