@@ -122,6 +122,21 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         doExecuteMergeAll(false, 19, parameters);
     }
 
+    @Test
+    public void executeMergeAllRetainingOutlineTocNamesWhenNamesAreVeryLong() throws IOException {
+        MergeParameters parameters = setUpParameters(getInput());
+        String longFilename = "This is a file that has a very long name and should not be truncated so that the version is visible at the end (but when applied to the footer the name should be truncated not to cover the page number) v7";
+        parameters.addInput(new PdfMergeInput(customInput("pdf/with_meta.pdf", longFilename + ".pdf")));
+        parameters.setTableOfContentsPolicy(ToCPolicy.FILE_NAMES);
+        parameters.setFilenameFooter(true);
+        doExecuteMergeAll(false, 19, parameters);
+
+        testContext.forPdfOutput(d -> {
+            assertPageTextContains(d.getPage(0), longFilename);
+            assertFooterHasText(d.getPage(16), longFilename.substring(0, 120) + " 17");
+        });
+    }
+
     @Test
     public void executeMergeRotatedTocPage() throws IOException {
         MergeParameters parameters = new MergeParameters();
@@ -393,13 +408,15 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         parameters.addInput(new PdfMergeInput(customInput("pdf/A4Portrait.pdf")));
         parameters.addInput(new PdfMergeInput(customInput("pdf/A3Landscape.pdf")));
         parameters.addInput(new PdfMergeInput(customInput("pdf/A3Portrait.pdf")));
+        parameters.addInput(new PdfMergeInput(customInput("pdf/landscape_by_rotation.pdf")));
+        parameters.addInput(new PdfMergeInput(customInput("pdf/potrait_by_rotation.pdf")));
         parameters.setNormalizePageSizes(true);
 
         testContext.pdfOutputTo(parameters);
         execute(parameters);
 
         testContext.assertTaskCompleted();
-        testContext.assertPages(3).forEachPdfOutput(d -> {
+        testContext.assertPages(5).forEachPdfOutput(d -> {
             assertEquals(595, widthOfCropBox(d.getPage(0)), 1);
 
             // landscape should be handled in a special case
@@ -407,6 +424,9 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
             assertEquals(840, widthOfCropBox(d.getPage(1)), 1);
 
             assertEquals(595, widthOfCropBox(d.getPage(2)), 1);
+
+            assertEquals(840, widthOfCropBox(d.getPage(3)), 1);
+            assertEquals(595, widthOfCropBox(d.getPage(4)), 1);
         });
     }
 
@@ -417,13 +437,15 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
         parameters.addInput(new PdfMergeInput(customInput("pdf/A3Landscape.pdf")));
         parameters.addInput(new PdfMergeInput(customInput("pdf/A4Portrait.pdf")));
         parameters.addInput(new PdfMergeInput(customInput("pdf/A3Portrait.pdf")));
+        parameters.addInput(new PdfMergeInput(customInput("pdf/landscape_by_rotation.pdf")));
+        parameters.addInput(new PdfMergeInput(customInput("pdf/potrait_by_rotation.pdf")));
         parameters.setNormalizePageSizes(true);
 
         testContext.pdfOutputTo(parameters);
         execute(parameters);
 
         testContext.assertTaskCompleted();
-        testContext.assertPages(3).forEachPdfOutput(d -> {
+        testContext.assertPages(5).forEachPdfOutput(d -> {
             assertEquals(1190, widthOfCropBox(d.getPage(0)), 1);
 
             // landscape should be handled in a special case
@@ -431,6 +453,27 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
             assertEquals(841, widthOfCropBox(d.getPage(1)), 1);
 
             assertEquals(841, widthOfCropBox(d.getPage(2)), 1);
+
+            assertEquals(1190, widthOfCropBox(d.getPage(3)), 1);
+            assertEquals(841, widthOfCropBox(d.getPage(4)), 1);
+        });
+    }
+
+    @Test
+    public void normalizePageSizes_AllLandscape() throws IOException {
+        MergeParameters parameters = new MergeParameters();
+        parameters.setExistingOutputPolicy(ExistingOutputPolicy.OVERWRITE);
+        parameters.addInput(new PdfMergeInput(customInput("pdf/A3Landscape.pdf")));
+        parameters.addInput(new PdfMergeInput(customInput("pdf/landscape_by_rotation.pdf")));
+        parameters.setNormalizePageSizes(true);
+
+        testContext.pdfOutputTo(parameters);
+        execute(parameters);
+
+        testContext.assertTaskCompleted();
+        testContext.assertPages(2).forEachPdfOutput(d -> {
+            assertEquals(1190, widthOfCropBox(d.getPage(0)), 1);
+            assertEquals(1190, widthOfCropBox(d.getPage(1)), 1);
         });
     }
 
@@ -529,7 +572,7 @@ public class MergeSamboxTaskTest extends BaseTaskTest<MergeParameters> {
     }
 
     private float widthOfCropBox(PDPage page) {
-        return page.getCropBox().getWidth();
+        return page.getCropBox().rotate(page.getRotation()).getWidth();
     }
 
     private float heightOfCropBox(PDPage page) {
